@@ -122,6 +122,52 @@ def ReadIqw( FileName, iqiq = True):
 
 
 
+def WriteBin( iqData, fSamplingRate, FileName):
+    """Writes a bin file, e.g. for use on KS generators
+    iqData can be a list of complex or list of floats (iqiqiq format mandatory).
+    writtenSamples = WriteBin("MyFile.bin",complexList, fs)"""
+    
+    import struct
+    from datetime import date
+    import math
+    import logging
+    
+    #check if iqData is complex
+    if isinstance( iqData[0], complex):
+        iqData = Complex2Iqiq( iqData)
+        
+    NumberOfSamples = len(iqData) // 2
+         
+    #Find maximum magnitude and scale for max to be FullScale (1.0)
+    power = []
+    for n in range(NumberOfSamples):
+        power.append(abs(iqData[2*n]**2 + iqData[2*n+1]**2))
+    scaling = math.sqrt( max(power))
+    
+    # normalize to magnitude 1
+    iqData = [ iq / scaling for iq in iqData]
+    
+    #calculate rms in dB (below full scale)
+    rms = math.sqrt(sum(power)/NumberOfSamples)/scaling
+    rms = abs(20*math.log10( rms))
+    # Convert to int16, use floor function, otherwise distribution is not correct
+    iqData = [ math.floor(iq * 32767 +.5) for iq in iqData]
+        
+    try:
+        file = open( FileName, "wb")
+
+        # binary block, big endian
+        for nIdx in range(len(iqData)):
+            file.write( struct.pack(">h",iqData[nIdx]))
+
+        file.close()
+    except:
+        logging.error("File (" + FileName +") write error!" )
+        
+    return NumberOfSamples
+
+
+
 def WriteWv( iqData, fSamplingRate, FileName):
     """Writes a WV file.
     iqData can be a list of complex or list of floats (iqiqiq format mandatory).
@@ -155,6 +201,7 @@ def WriteWv( iqData, fSamplingRate, FileName):
         
     try:
         file = open( FileName, "wb")
+
         file.write( "{TYPE: SMU-WV,0}".encode("ASCII"))
         file.write( "{COMMENT: R&S WaveForm, TheAE-RA}".encode("ASCII"))
         file.write( ("{DATE: " + str(date.today())+ "}").encode("ASCII"))
@@ -169,9 +216,12 @@ def WriteWv( iqData, fSamplingRate, FileName):
     #        fprintf(file_id,'%s',['{MARKER LIST 1: ' num2str(m1start) ':1;' num2str(m1stop) ':0}']);
     #    end
         file.write( ("{WAVEFORM-" +  str(4*NumberOfSamples+1) + ": #").encode("ASCII"))
-        
+
+        # binary block
         file.write( struct.pack("h"*len(iqData),*iqData))
+        
         file.write( "}".encode("ASCII"))
+
         file.close()
     except:
         logging.error("File (" + FileName +") write error!" )
