@@ -5,13 +5,20 @@ Created on Tue Feb 19 15:02:17 2019
 @authors: RAMIAN, TIPTON
 """
 
-
+from enum import Enum
+import math
+import socket
+import logging
+import struct
+import timeit
+import time
 
 class instrument(object):
-        
-    """Python class implementing a raw socket connection client, 
-    mainly designed around instrument control"""
-    
+    '''
+    Python class implementing a raw socket connection client,
+    mainly designed around instrument control
+    '''
+
     __ipaddress = ""
     __port = 5025
     __sendcls = True
@@ -23,41 +30,45 @@ class instrument(object):
     _InBufferSize = 4* 2**10   #4kByte
     __IDString = ""
     __Options = None
-    
-    from enum import Enum
+
+
     class SyncMethod(Enum):
+        '''
+        enum class supporting different sync methods
+        '''
         OpcQuery = 0
         Blocking = 1
         StbPoll = 2
 
 
-
     @staticmethod
     def GetNumberOfDigits( number):
-        import math
+        '''
+        count number of digits
+        '''
 
         if number < 0:
             number *= -1
         if number == 0:
             return 1
-    
+
         return math.ceil(math.log10( number))
 
 
-
     def __init__(self, IpAddress, port=5025, timeout = 2, sendcls = True):
-        """init method;
+        '''
+        init method;
             IP Address is required
             port            : port to communicate with
             timeout         : timeout value
-            sendcls         : clear error queue before communicating to instrument"""
+            sendcls         : clear error queue before communicating to instrument
+        '''
         self.__ipaddress = IpAddress
         self.__port = port
         self.__timeout = timeout
         self.__sendcls = sendcls
 
 
-
     def __del__(self):
         if self.__msocket:
             self.__msocket.close()
@@ -65,37 +76,40 @@ class instrument(object):
             self.__LogFile.close()
 
 
-
     def __QueryID(self):
         self.Write("*IDN?")
         self.__IDString = self.Read()
 
 
-
     def GetID(self):
-        if self.__IDString == "":
+        '''
+        return the instrument's ID string
+        '''
+        if self.__IDString == '':
             self.__QueryID()
         return self.__IDString
 
 
-
     def __QueryOpt(self):
         self.Write("*OPT?")
         self.__Options = self.Read().split(",")
         self.__Options.remove("")
 
 
-
     def GetOpt(self):
+        '''
+        return the instrument's option string
+        '''
         if self.__Options == None:
             self.__QueryOpt()
         return self.__Options
 
 
-
     def SetTimeout( self, timeout):
-        """Set the timeout for the connection (non blocking socket).
-        For a blocking socket, use 'None'"""
+        '''
+        Set the timeout for the connection (non blocking socket).
+        For a blocking socket, use 'None'
+        '''
         self.__timeout = timeout
         try:
             self.__msocket.settimeout( self.__timeout)
@@ -105,13 +119,14 @@ class instrument(object):
 
 
     def GetTimeout( self):
-        """Returns the specified timeout, 'None' meaning blocking socket"""
+        '''
+        Returns the specified timeout, 'None' meaning blocking socket
+        '''
         return self.__msocket.gettimeout()
 
 
-
     def Synchronize( self, method = SyncMethod.StbPoll, timeout = None ):
-        """Function to synchronize with instruments.
+        '''Function to synchronize with instruments.
         Input:
         SyncMethod:
             SyncMethod.OpcQUery:    Use *OPC? to synchronize, i.e. a blocking query
@@ -120,11 +135,9 @@ class instrument(object):
         timeout:    Timeout value, before function returns with timeout error
 
         Output:
-        SyncOk: returns 1 when sync was successful, or 0 on timeout"""
+        SyncOk: returns 1 when sync was successful, or 0 on timeout
+        '''
 
-        import socket
-        import timeit
-        import time
         SyncOk = 0
 
         # Save current timeout and set user timeout
@@ -136,7 +149,7 @@ class instrument(object):
 
         # OPC Query Sync mode
         if method == self.SyncMethod.OpcQuery:
-            self.Write( "*OPC?")
+            self.Write( '*OPC?')
             try:
                 value = int(self.Read())
                 if value == 1:
@@ -146,14 +159,14 @@ class instrument(object):
 
         # *WAI blocking mode
         if method == self.SyncMethod.Blocking:
-            self.Write( "*WAI")
+            self.Write( '*WAI')
 
          # *ESR? polling mode
         if method == self.SyncMethod.StbPoll:
-            self.Write( "*OPC")
+            self.Write( '*OPC')
             start = timeit.default_timer()
             while( not SyncOk and ((timeit.default_timer()-start)<=self.__timeout) ):
-                SyncOk = int(self.Query( "*ESR?")) & 1
+                SyncOk = int(self.Query( '*ESR?')) & 1
                 #sleep for 2 ms, so we don't poll too often
                 time.sleep( .002)
 
@@ -165,8 +178,9 @@ class instrument(object):
 
 
     def Connect( self, getID = True, getOptions = False, Preset = False):
-        """Connects to the specified instrument and opens the connection"""
-        import socket
+        '''
+        Connects to the specified instrument and opens the connection
+        '''
 
         try:
             self.__msocket = socket.socket( socket.AF_INET, socket.SOCK_STREAM)
@@ -174,10 +188,10 @@ class instrument(object):
             self.__msocket.connect( (self.__ipaddress, self.__port))
             self.__msocket.settimeout( self.__timeout)
             if Preset:
-                self.Query( "*RST;*OPC?")
+                self.Query( '*RST;*OPC?')
             #Clear Error Queue
             if self.__sendcls:
-                self.Write( "*CLS")
+                self.Write( '*CLS')
             if getID:
                 self.__QueryID()
             if getOptions:
@@ -186,69 +200,73 @@ class instrument(object):
             return -1
         except TimeoutError:
             return -1
-        
+
         return 0
 
 
-
     def Close( self):
-        """Closes the connection"""
+        '''
+        Closes the connection
+        '''
 
         self.CloseSocket()
         return
 
 
-
     def StartLogging( self, FileName, ClearFile = False, LogReadings = True):
-        """Start logging into FileName
-        ClearFile deletes file, if set to True"""
-        FileMode = "a"
+        '''
+        Start logging into FileName
+        ClearFile deletes file, if set to True
+        '''
+        FileMode = 'a'
         if ClearFile:
-            FileMode = "w"
+            FileMode = 'w'
         self.__LogFile = open( FileName, FileMode)
         self.__LogReadings = LogReadings
 
 
-
     def StopLogging( self):
-        """Stop logging"""
+        '''
+        Stop logging
+        '''
         self.__LogFile.close()
         self.__LogFile = None
 
 
-
     def ___LogToFile( self, Command):
-        if self.__LogFile == None:
+        if self.__LogFile is None:
             return -1
         
         self.__LogFile.write(Command+"\n")
         return 0
 
 
-
     def Write( self, Command, Binary = False, AddTermination = True):
-        """Write a command; termination character (\n) automatically added"""
+        '''
+        Write a command; termination character (\n) automatically added
+        '''
         
-        if self.__msocket == None:
-            raise Exception("Connection is closed, use connect first!")
+        if self.__msocket is None:
+            raise Exception('Connection is closed, use connect first!')
         
         self.___LogToFile( Command)
         if AddTermination:
-            if Command.endswith("\n") == False:
+            if Command.endswith("\n") is False:
                 Command = Command + "\n"
         if Binary:
             self.__msocket.sendall( Command)
         else:
-            self.__msocket.sendall( Command.encode("ASCII"))
+            self.__msocket.sendall( Command.encode('ASCII'))
 
           
 
     def Read( self, decode = True, NumberOfBytes = -1):
-        """Read back from the connected instrument"""
-        import logging
+        '''
+        Read back from the connected instrument
+        '''
 
-        if self.__msocket == None:
-            raise Exception("Connection is closed, use connect first!")
+        if self.__msocket is None:
+            raise Exception('Connection is closed, use connect first!')
 
         if NumberOfBytes == -1:
             NumberOfBytes = self._InBufferSize
@@ -315,7 +333,6 @@ class instrument(object):
     def UseNaN( self, vfcData):
         """Replace the SCPI representation of NaN (9.91*10^37) by NaN"""
 
-        import math
         return [math.nan if x > 9.909e37 else x for x in vfcData]
 
 
@@ -332,10 +349,7 @@ class instrument(object):
             data vector when ReturnSamples is true
             byte counter when ReturnSamples is false
             """
-        
-        import struct
-        import logging
-        
+
         digits = self.Read( NumberOfBytes = 2)
 
         if digits[1] == "(":
